@@ -261,7 +261,7 @@ Usage::
     search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
     ```
 """
-from mypy_boto3_ec2.client import EC2Client, EC2Client as Client
+from mypy_boto3_ec2.client import EC2Client as Client, EC2Client
 from mypy_boto3_ec2.paginator import (
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
@@ -352,8 +352,8 @@ from mypy_boto3_ec2.paginator import (
     SearchTransitGatewayMulticastGroupsPaginator,
 )
 from mypy_boto3_ec2.service_resource import (
-    EC2ServiceResource,
     EC2ServiceResource as ServiceResource,
+    EC2ServiceResource,
 )
 from mypy_boto3_ec2.waiter import (
     BundleTaskCompleteWaiter,
